set -e
set +x

echo "build ios start"

BUILD_TYPE=$"Release"
BUILD_BRANCH=`git symbolic-ref HEAD 2>/dev/null | cut -d"/" -f 3`
BUILD_COMMIT_ID=`git rev-parse --short HEAD`

echo "===================================== "
echo "BUILD_TYPE: ${BUILD_TYPE}"
echo "BUILD_BRANCH: ${BUILD_BRANCH}"
echo "BUILD_COMMIT_ID: ${BUILD_COMMIT_ID}"
echo "===================================== "

project_path=$(pwd)

flutter pub upgrade

flutter build ios

cd $project_path/ios

now=$(date +"%Y%m%d%H%M")

scheme="Runner"

configuration=${BUILD_TYPE}

#指定打包所使用的输出方式，目前支持app-store, package, ad-hoc, enterprise, development, 和developer-id，即xcodebuild的method参数
export_method="development"

#指定项目地址
workspace_path="${project_path}/ios/Runner.xcodeproj"
#指定输出路径
rm -rf "${project_path}/outputs/app/ios"
rm -rf "${project_path}/outputs/symbol/ios"
mkdir -p "${project_path}/outputs/app/ios"
mkdir -p "${project_path}/outputs/symbol/ios"
output_path_app="${project_path}/outputs/app/ios"
output_path_symbol="${project_path}/outputs/symbol/ios"


#指定输出归档文件地址
archive_path="$output_path_symbol/meeting_flutter_${export_method}_${now}.xcarchive"
#指定输出ipa地址
ipa_path="$output_path_app/meeting_flutter_${BUILD_TYPE}_${BUILD_BRANCH}_${BUILD_COMMIT_ID}_${now}.ipa"
#指定输出ipa名称
ipa_name="meeting_flutter_${BUILD_TYPE}_${BUILD_COMMIT_ID}_${now}.ipa"
# 指定导出ipa包需要用到的plist配置文件的路径
#export_options_plist_path="${project_path}/deploy/ExportOptions.plist"


#输出设定的变量值
echo "===================================== "
echo "workspace path: ${workspace_path}"
echo "archive path: ${archive_path}"
echo "ipa path: ${ipa_path}"
echo "export method: ${export_method}"
echo "===================================== "

fastlane gym --scheme ${scheme} --clean --configuration ${configuration} --archive_path ${archive_path} --export_method ${export_method}  --output_directory ${output_path_app} --output_name ${ipa_name}


echo "build ios done"

set +e
